import React, { forwardRef, useRef, useEffect, Fragment } from 'react';
import Glide$1 from '@glidejs/glide';
import '@glidejs/glide/dist/css/glide.core.min.css';

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var styles = {
  position: 'relative',
  width: '100%',
  overflow: 'hidden',
  boxSizing: 'border-box'
};
var defaultProps = {
  children: null,
  style: {},
  className: 'glide',
  hideArrows: false,
  leftArrowComponent: null,
  rightArrowComponent: null,
  type: 'slider',
  startAt: 0,
  perView: 1,
  focusAt: 0,
  gap: 10,
  autoplay: false,
  hoverPause: true,
  keyboard: true,
  bound: false,
  swipeThreshold: 80,
  dragThreshold: 120,
  perTouch: false,
  touchRatio: 0.5,
  touchAngle: 45,
  animationDuration: 400,
  rewind: true,
  rewindDuration: 800,
  animationTimingFunc: 'cubic-bezier(0.165, 0.840, 0.440, 1.000)',
  direction: 'ltr',
  peek: 0,
  breakpoints: {},
  classes: {
    direction: {
      ltr: 'glide--ltr',
      rtl: 'glide--rtl'
    },
    slider: 'glide--slider',
    carousel: 'glide--carousel',
    swipeable: 'glide--swipeable',
    dragging: 'glide--dragging',
    cloneSlide: 'glide__slide--clone',
    activeNav: 'glide__bullet--active',
    activeSlide: 'glide__slide--active',
    disabledArrow: 'glide__arrow--disabled'
  },
  throttle: 25
};
var Glide = forwardRef(function (props, ref) {
  if (props === void 0) {
    props = defaultProps;
  }

  var glideRef = useRef(null);
  useEffect(function () {
    var glide = new Glide$1(ref ? ref.current : glideRef.current, props);
    glide.mount();
    return function () {
      return glide.destroy();
    };
  }, []);
  var _props = props,
      children = _props.children,
      className = _props.className,
      style = _props.style,
      hideArrows = _props.hideArrows,
      leftArrowComponent = _props.leftArrowComponent,
      rightArrowComponent = _props.rightArrowComponent;
  return React.createElement("div", {
    className: className,
    ref: ref || glideRef,
    style: _extends({}, styles, {}, style)
  }, React.createElement("div", {
    className: "slider__track glide__track",
    "data-glide-el": "track"
  }, React.createElement("ul", {
    className: "glide__slides"
  }, children.map(function (slide, index) {
    return React.createElement(Fragment, {
      key: index
    }, slide);
  }))), !hideArrows && React.createElement("div", {
    style: {
      height: 0
    },
    "data-glide-el": "controls"
  }, React.createElement("button", {
    "data-glide-dir": "<"
  }, leftArrowComponent ? leftArrowComponent : '<'), React.createElement("button", {
    "data-glide-dir": ">"
  }, rightArrowComponent ? rightArrowComponent : '>')));
});

var Slide = (function (_ref) {
  var children = _ref.children,
      className = _ref.className,
      props = _objectWithoutPropertiesLoose(_ref, ["children", "className"]);

  return React.createElement("li", Object.assign({
    className: "glide__slide " + (className || '')
  }, props), children);
});

export default Glide;
export { Slide };
//# sourceMappingURL=index.modern.js.map
